==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_shader_f_f_p_render_state_8h.js <==
var _ogre_shader_f_f_p_render_state_8h =
[
    [ "Ogre::RTShader::FFPVertexShaderStage", "group___r_t_shader.html#ga7d20b2397c3eab2b52ec405863c6f274", [
      [ "Ogre::RTShader::FFP_VS_PRE_PROCESS", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274ad955465ff061413a966f568fc187599e", null ],
      [ "Ogre::RTShader::FFP_VS_TRANSFORM", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a04f47ef20926c0a10951eb3d6fa9af91", null ],
      [ "Ogre::RTShader::FFP_VS_COLOUR", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a5f213e0b61cc3a0bae05704eac26fa35", null ],
      [ "Ogre::RTShader::FFP_VS_LIGHTING", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274afdb7e1c00705255e5a10459e723e9acd", null ],
      [ "Ogre::RTShader::FFP_VS_TEXTURING", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a498dcf4231b63a549b001420ea5692ff", null ],
      [ "Ogre::RTShader::FFP_VS_FOG", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a8b4930a3fd90d5b7222960fc5727b8cf", null ],
      [ "Ogre::RTShader::FFP_VS_POST_PROCESS", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274acc37fcb1e383c065bd730c7ac13fde90", null ]
    ] ],
    [ "Ogre::RTShader::FFPFragmentShaderStage", "group___r_t_shader.html#ga06b7172046e21956b5eb485dbd7fc29a", [
      [ "Ogre::RTShader::FFP_PS_PRE_PROCESS", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa326b1eb04022c84f9151bac6663dc40d", null ],
      [ "Ogre::RTShader::FFP_PS_COLOUR_BEGIN", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa776dac89aa5e4d06186a5dcb20a3fa9b", null ],
      [ "Ogre::RTShader::FFP_PS_SAMPLING", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa8cdc0e4095b09efda2fa34e203cb8b61", null ],
      [ "Ogre::RTShader::FFP_PS_TEXTURING", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aab325d310fd56d8564be69550b319ecc5", null ],
      [ "Ogre::RTShader::FFP_PS_COLOUR_END", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aadff5a4ef68640ae288c15265b3f8fc3b", null ],
      [ "Ogre::RTShader::FFP_PS_FOG", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aad8d2dd505e7f3d5c87c738e6afa0d4fc", null ],
      [ "Ogre::RTShader::FFP_PS_POST_PROCESS", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa0514e394e633d17623c38771d7e5d917", null ],
      [ "Ogre::RTShader::FFP_PS_ALPHA_TEST", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa7ae09e0eaa0207d35c1cc4c74513cc5d", null ]
    ] ],
    [ "Ogre::RTShader::FFPShaderStage", "group___r_t_shader.html#ga4c92eba13eb8038d35530610c58ceff4", [
      [ "Ogre::RTShader::FFP_PRE_PROCESS", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a3c4091f2a0e44643b34801419c0ea987", null ],
      [ "Ogre::RTShader::FFP_TRANSFORM", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a89872e19110c14f19fa11bd6c04755c4", null ],
      [ "Ogre::RTShader::FFP_COLOUR", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4ad2c91bf8902fec593abd2d6471d7d05c", null ],
      [ "Ogre::RTShader::FFP_LIGHTING", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a4981bd811954d8abdb7623226e81d9ab", null ],
      [ "Ogre::RTShader::FFP_TEXTURING", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a4633e1da9bc8ecbdecf34cd5cc4918d0", null ],
      [ "Ogre::RTShader::FFP_FOG", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4affe0e1ca62c12578c98893daced6125e", null ],
      [ "Ogre::RTShader::FFP_POST_PROCESS", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a11352bb182b27667fa58e81cd75a5b21", null ],
      [ "Ogre::RTShader::FFP_ALPHA_TEST", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a028cd01c8dfcc08f10f9b3de20d1c604", null ]
    ] ]
];

==> ogre-14.5.2-1.1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_shader_f_f_p_render_state_8h.js <==
var _ogre_shader_f_f_p_render_state_8h =
[
    [ "Ogre::RTShader::FFPVertexShaderStage", "group___r_t_shader.html#ga7d20b2397c3eab2b52ec405863c6f274", [
      [ "Ogre::RTShader::FFP_VS_PRE_PROCESS", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274ad955465ff061413a966f568fc187599e", null ],
      [ "Ogre::RTShader::FFP_VS_TRANSFORM", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a04f47ef20926c0a10951eb3d6fa9af91", null ],
      [ "Ogre::RTShader::FFP_VS_COLOUR", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a5f213e0b61cc3a0bae05704eac26fa35", null ],
      [ "Ogre::RTShader::FFP_VS_LIGHTING", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274afdb7e1c00705255e5a10459e723e9acd", null ],
      [ "Ogre::RTShader::FFP_VS_TEXTURING", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a498dcf4231b63a549b001420ea5692ff", null ],
      [ "Ogre::RTShader::FFP_VS_FOG", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a8b4930a3fd90d5b7222960fc5727b8cf", null ],
      [ "Ogre::RTShader::FFP_VS_POST_PROCESS", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274acc37fcb1e383c065bd730c7ac13fde90", null ]
    ] ],
    [ "Ogre::RTShader::FFPFragmentShaderStage", "group___r_t_shader.html#ga06b7172046e21956b5eb485dbd7fc29a", [
      [ "Ogre::RTShader::FFP_PS_PRE_PROCESS", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa326b1eb04022c84f9151bac6663dc40d", null ],
      [ "Ogre::RTShader::FFP_PS_COLOUR_BEGIN", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa776dac89aa5e4d06186a5dcb20a3fa9b", null ],
      [ "Ogre::RTShader::FFP_PS_SAMPLING", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa8cdc0e4095b09efda2fa34e203cb8b61", null ],
      [ "Ogre::RTShader::FFP_PS_TEXTURING", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aab325d310fd56d8564be69550b319ecc5", null ],
      [ "Ogre::RTShader::FFP_PS_ALPHA_TEST", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa7ae09e0eaa0207d35c1cc4c74513cc5d", null ],
      [ "Ogre::RTShader::FFP_PS_COLOUR_END", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aadff5a4ef68640ae288c15265b3f8fc3b", null ],
      [ "Ogre::RTShader::FFP_PS_PBR_LIGHTING_BEGIN", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa5d70a2dcd472e9147a0f4e9a3b8fb087", null ],
      [ "Ogre::RTShader::FFP_PS_PBR_LIGHTING_END", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa0280a442cee0d4522813d0319e281d7e", null ],
      [ "Ogre::RTShader::FFP_PS_FOG", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aad8d2dd505e7f3d5c87c738e6afa0d4fc", null ],
      [ "Ogre::RTShader::FFP_PS_POST_PROCESS", "group___r_t_shader.html#gga06b7172046e21956b5eb485dbd7fc29aa0514e394e633d17623c38771d7e5d917", null ]
    ] ],
    [ "Ogre::RTShader::FFPShaderStage", "group___r_t_shader.html#ga4c92eba13eb8038d35530610c58ceff4", [
      [ "Ogre::RTShader::FFP_PRE_PROCESS", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a3c4091f2a0e44643b34801419c0ea987", null ],
      [ "Ogre::RTShader::FFP_TRANSFORM", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a89872e19110c14f19fa11bd6c04755c4", null ],
      [ "Ogre::RTShader::FFP_COLOUR", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4ad2c91bf8902fec593abd2d6471d7d05c", null ],
      [ "Ogre::RTShader::FFP_LIGHTING", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a4981bd811954d8abdb7623226e81d9ab", null ],
      [ "Ogre::RTShader::FFP_TEXTURING", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a4633e1da9bc8ecbdecf34cd5cc4918d0", null ],
      [ "Ogre::RTShader::FFP_FOG", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4affe0e1ca62c12578c98893daced6125e", null ],
      [ "Ogre::RTShader::FFP_POST_PROCESS", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a11352bb182b27667fa58e81cd75a5b21", null ],
      [ "Ogre::RTShader::FFP_ALPHA_TEST", "group___r_t_shader.html#gga4c92eba13eb8038d35530610c58ceff4a028cd01c8dfcc08f10f9b3de20d1c604", null ]
    ] ]
];
